/****************************************************************************
** Meta object code from reading C++ file 'accountmanager.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.18)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../src/dataManage/accountmanager.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'accountmanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.18. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_AccountManager_t {
    QByteArrayData data[20];
    char stringdata0[370];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_AccountManager_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_AccountManager_t qt_meta_stringdata_AccountManager = {
    {
QT_MOC_LITERAL(0, 0, 14), // "AccountManager"
QT_MOC_LITERAL(1, 15, 22), // "signalDataInitFinished"
QT_MOC_LITERAL(2, 38, 0), // ""
QT_MOC_LITERAL(3, 39, 19), // "signalAccountUpdate"
QT_MOC_LITERAL(4, 59, 27), // "signalGeneralSettingsUpdate"
QT_MOC_LITERAL(5, 87, 23), // "signalAccountDataUpdate"
QT_MOC_LITERAL(6, 111, 20), // "signalScheduleUpdate"
QT_MOC_LITERAL(7, 132, 24), // "signalScheduleTypeUpdate"
QT_MOC_LITERAL(8, 157, 26), // "signalSearchScheduleUpdate"
QT_MOC_LITERAL(9, 184, 24), // "signalAccountStateChange"
QT_MOC_LITERAL(10, 209, 13), // "signalSyncNum"
QT_MOC_LITERAL(11, 223, 3), // "num"
QT_MOC_LITERAL(12, 227, 12), // "signalLogout"
QT_MOC_LITERAL(13, 240, 14), // "DAccount::Type"
QT_MOC_LITERAL(14, 255, 24), // "slotGetAccountListFinish"
QT_MOC_LITERAL(15, 280, 14), // "DAccount::List"
QT_MOC_LITERAL(16, 295, 11), // "accountList"
QT_MOC_LITERAL(17, 307, 28), // "slotGetGeneralSettingsFinish"
QT_MOC_LITERAL(18, 336, 29), // "DCalendarGeneralSettings::Ptr"
QT_MOC_LITERAL(19, 366, 3) // "ptr"

    },
    "AccountManager\0signalDataInitFinished\0"
    "\0signalAccountUpdate\0signalGeneralSettingsUpdate\0"
    "signalAccountDataUpdate\0signalScheduleUpdate\0"
    "signalScheduleTypeUpdate\0"
    "signalSearchScheduleUpdate\0"
    "signalAccountStateChange\0signalSyncNum\0"
    "num\0signalLogout\0DAccount::Type\0"
    "slotGetAccountListFinish\0DAccount::List\0"
    "accountList\0slotGetGeneralSettingsFinish\0"
    "DCalendarGeneralSettings::Ptr\0ptr"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_AccountManager[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      13,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
      11,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   79,    2, 0x06 /* Public */,
       3,    0,   80,    2, 0x06 /* Public */,
       4,    0,   81,    2, 0x06 /* Public */,
       5,    0,   82,    2, 0x06 /* Public */,
       6,    0,   83,    2, 0x06 /* Public */,
       7,    0,   84,    2, 0x06 /* Public */,
       8,    0,   85,    2, 0x06 /* Public */,
       9,    0,   86,    2, 0x06 /* Public */,
      10,    1,   87,    2, 0x06 /* Public */,
      10,    0,   90,    2, 0x26 /* Public | MethodCloned */,
      12,    1,   91,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      14,    1,   94,    2, 0x0a /* Public */,
      17,    1,   97,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   11,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 13,    2,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 15,   16,
    QMetaType::Void, 0x80000000 | 18,   19,

       0        // eod
};

void AccountManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<AccountManager *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->signalDataInitFinished(); break;
        case 1: _t->signalAccountUpdate(); break;
        case 2: _t->signalGeneralSettingsUpdate(); break;
        case 3: _t->signalAccountDataUpdate(); break;
        case 4: _t->signalScheduleUpdate(); break;
        case 5: _t->signalScheduleTypeUpdate(); break;
        case 6: _t->signalSearchScheduleUpdate(); break;
        case 7: _t->signalAccountStateChange(); break;
        case 8: _t->signalSyncNum((*reinterpret_cast< const int(*)>(_a[1]))); break;
        case 9: _t->signalSyncNum(); break;
        case 10: _t->signalLogout((*reinterpret_cast< DAccount::Type(*)>(_a[1]))); break;
        case 11: _t->slotGetAccountListFinish((*reinterpret_cast< DAccount::List(*)>(_a[1]))); break;
        case 12: _t->slotGetGeneralSettingsFinish((*reinterpret_cast< DCalendarGeneralSettings::Ptr(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (AccountManager::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&AccountManager::signalDataInitFinished)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (AccountManager::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&AccountManager::signalAccountUpdate)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (AccountManager::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&AccountManager::signalGeneralSettingsUpdate)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (AccountManager::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&AccountManager::signalAccountDataUpdate)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (AccountManager::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&AccountManager::signalScheduleUpdate)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (AccountManager::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&AccountManager::signalScheduleTypeUpdate)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (AccountManager::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&AccountManager::signalSearchScheduleUpdate)) {
                *result = 6;
                return;
            }
        }
        {
            using _t = void (AccountManager::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&AccountManager::signalAccountStateChange)) {
                *result = 7;
                return;
            }
        }
        {
            using _t = void (AccountManager::*)(const int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&AccountManager::signalSyncNum)) {
                *result = 8;
                return;
            }
        }
        {
            using _t = void (AccountManager::*)(DAccount::Type );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&AccountManager::signalLogout)) {
                *result = 10;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject AccountManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_AccountManager.data,
    qt_meta_data_AccountManager,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *AccountManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AccountManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_AccountManager.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int AccountManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 13;
    }
    return _id;
}

// SIGNAL 0
void AccountManager::signalDataInitFinished()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void AccountManager::signalAccountUpdate()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void AccountManager::signalGeneralSettingsUpdate()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void AccountManager::signalAccountDataUpdate()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void AccountManager::signalScheduleUpdate()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void AccountManager::signalScheduleTypeUpdate()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void AccountManager::signalSearchScheduleUpdate()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void AccountManager::signalAccountStateChange()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void AccountManager::signalSyncNum(const int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 8, _a);
}

// SIGNAL 10
void AccountManager::signalLogout(DAccount::Type _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 10, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
