/****************************************************************************
** Meta object code from reading C++ file 'dunioniddav_p.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.18)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../src/unionIDDav/dunioniddav_p.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dunioniddav_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.18. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_DUIDSynDataWorker_t {
    QByteArrayData data[11];
    char stringdata0[133];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_DUIDSynDataWorker_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_DUIDSynDataWorker_t qt_meta_stringdata_DUIDSynDataWorker = {
    {
QT_MOC_LITERAL(0, 0, 17), // "DUIDSynDataWorker"
QT_MOC_LITERAL(1, 18, 12), // "signalUpdate"
QT_MOC_LITERAL(2, 31, 0), // ""
QT_MOC_LITERAL(3, 32, 26), // "DDataSyncBase::UpdateTypes"
QT_MOC_LITERAL(4, 59, 10), // "updateType"
QT_MOC_LITERAL(5, 70, 15), // "signalSyncState"
QT_MOC_LITERAL(6, 86, 9), // "syncState"
QT_MOC_LITERAL(7, 96, 8), // "syncData"
QT_MOC_LITERAL(8, 105, 9), // "SyncStack"
QT_MOC_LITERAL(9, 115, 8), // "syncType"
QT_MOC_LITERAL(10, 124, 8) // "slotSync"

    },
    "DUIDSynDataWorker\0signalUpdate\0\0"
    "DDataSyncBase::UpdateTypes\0updateType\0"
    "signalSyncState\0syncState\0syncData\0"
    "SyncStack\0syncType\0slotSync"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_DUIDSynDataWorker[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       4,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   34,    2, 0x06 /* Public */,
       5,    1,   37,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       7,    1,   40,    2, 0x0a /* Public */,
      10,    0,   43,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, QMetaType::Int,    6,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 8,    9,
    QMetaType::Void,

       0        // eod
};

void DUIDSynDataWorker::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<DUIDSynDataWorker *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->signalUpdate((*reinterpret_cast< const DDataSyncBase::UpdateTypes(*)>(_a[1]))); break;
        case 1: _t->signalSyncState((*reinterpret_cast< const int(*)>(_a[1]))); break;
        case 2: _t->syncData((*reinterpret_cast< SyncStack(*)>(_a[1]))); break;
        case 3: _t->slotSync(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (DUIDSynDataWorker::*)(const DDataSyncBase::UpdateTypes );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DUIDSynDataWorker::signalUpdate)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (DUIDSynDataWorker::*)(const int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DUIDSynDataWorker::signalSyncState)) {
                *result = 1;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject DUIDSynDataWorker::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_DUIDSynDataWorker.data,
    qt_meta_data_DUIDSynDataWorker,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *DUIDSynDataWorker::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DUIDSynDataWorker::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_DUIDSynDataWorker.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int DUIDSynDataWorker::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void DUIDSynDataWorker::signalUpdate(const DDataSyncBase::UpdateTypes _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void DUIDSynDataWorker::signalSyncState(const int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}
struct qt_meta_stringdata_DUnionIDDav__DUIDSynDataPrivate_t {
    QByteArrayData data[10];
    char stringdata0[144];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_DUnionIDDav__DUIDSynDataPrivate_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_DUnionIDDav__DUIDSynDataPrivate_t qt_meta_stringdata_DUnionIDDav__DUIDSynDataPrivate = {
    {
QT_MOC_LITERAL(0, 0, 31), // "DUnionIDDav::DUIDSynDataPrivate"
QT_MOC_LITERAL(1, 32, 12), // "signalUpdate"
QT_MOC_LITERAL(2, 45, 0), // ""
QT_MOC_LITERAL(3, 46, 26), // "DDataSyncBase::UpdateTypes"
QT_MOC_LITERAL(4, 73, 10), // "updateType"
QT_MOC_LITERAL(5, 84, 15), // "signalSyncState"
QT_MOC_LITERAL(6, 100, 9), // "syncState"
QT_MOC_LITERAL(7, 110, 14), // "signalSyncData"
QT_MOC_LITERAL(8, 125, 9), // "SyncStack"
QT_MOC_LITERAL(9, 135, 8) // "syncType"

    },
    "DUnionIDDav::DUIDSynDataPrivate\0"
    "signalUpdate\0\0DDataSyncBase::UpdateTypes\0"
    "updateType\0signalSyncState\0syncState\0"
    "signalSyncData\0SyncStack\0syncType"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_DUnionIDDav__DUIDSynDataPrivate[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       3,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       3,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   29,    2, 0x06 /* Public */,
       5,    1,   32,    2, 0x06 /* Public */,
       7,    1,   35,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, QMetaType::Int,    6,
    QMetaType::Void, 0x80000000 | 8,    9,

       0        // eod
};

void DUnionIDDav::DUIDSynDataPrivate::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<DUIDSynDataPrivate *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->signalUpdate((*reinterpret_cast< const DDataSyncBase::UpdateTypes(*)>(_a[1]))); break;
        case 1: _t->signalSyncState((*reinterpret_cast< const int(*)>(_a[1]))); break;
        case 2: _t->signalSyncData((*reinterpret_cast< const SyncStack(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (DUIDSynDataPrivate::*)(const DDataSyncBase::UpdateTypes );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DUIDSynDataPrivate::signalUpdate)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (DUIDSynDataPrivate::*)(const int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DUIDSynDataPrivate::signalSyncState)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (DUIDSynDataPrivate::*)(const SyncStack );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DUIDSynDataPrivate::signalSyncData)) {
                *result = 2;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject DUnionIDDav::DUIDSynDataPrivate::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_DUnionIDDav__DUIDSynDataPrivate.data,
    qt_meta_data_DUnionIDDav__DUIDSynDataPrivate,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *DUnionIDDav::DUIDSynDataPrivate::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DUnionIDDav::DUIDSynDataPrivate::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_DUnionIDDav__DUIDSynDataPrivate.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int DUnionIDDav::DUIDSynDataPrivate::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void DUnionIDDav::DUIDSynDataPrivate::signalUpdate(const DDataSyncBase::UpdateTypes _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void DUnionIDDav::DUIDSynDataPrivate::signalSyncState(const int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void DUnionIDDav::DUIDSynDataPrivate::signalSyncData(const SyncStack _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
